/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <alo17@hot.ee>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "ServerWnd.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h". 
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "ServerWnd.h"
#include "ServerListCtrl.h"

/*
 * CServerWnd class.
 */

BEGIN_EVENT_TABLE(CServerWnd,wxPanel)
	EVT_BUTTON(ID_ADDTOLIST, CServerWnd::AddNewServer)
	EVT_BUTTON(ID_UPDATE, CServerWnd::UpdateFromURL)
END_EVENT_TABLE()

/* 
 * Constructor for server window. Loads the server dialog and sets LogBook 
 * images.
 */
CServerWnd::CServerWnd( wxWindow *parent ) : wxPanel( parent ) {
	ServerWnd( this, TRUE ); 

	m_imagelist = new wxImageList(16, 16);
	m_imagelist->Add(Icons(1));
	m_imagelist->Add(Icons(2));
	
	m_logbook->AssignImageList(m_imagelist);            
	m_logbook->SetPageImage(0, 0);
	m_logbook->SetPageImage(1, 1);
	m_logbook->SetPageImage(2, 1);

}

/*
 * Destructor for server window. All shutdown functions go here.
 */
CServerWnd::~CServerWnd() {
}

/*
 * AddLogLine function adds a line of [text] into one of the three log
 * boxes in server window. Input variables are as follows:
 * [text]	The line of text to be added.
 * [target]	Target textctrl to add the line in. Can be one of these:
 *		ID_SERVERINFO 
 *		ID_LOG
 *		ID_DEBUGLOG
 * [statusbar]	If true, the line is also shown in status bar. Default: false
 */
void CServerWnd::AddLogLine(wxString text, int target, bool statusbar) {
	wxDateTime now = wxDateTime::Now();
	
	GetDlgItem(target)->AppendText(wxString::Format(
		wxT("[%s] %s\n"), now.Format(wxT("%c")).c_str(), text.c_str())
	);
		
	GetDlgItem(target)->ShowPosition(GetDlgItem(target)->GetLastPosition());
		
	if (statusbar) {
		xmuleDlg->SetStatusText(text, 0);
	}	
}

/*
 * Add new server to servers list.
 */
void CServerWnd::AddNewServer() {
	AddLogLine(wxT("Add New Server button clicked."), ID_DEBUGLOG);
}

/*
 * Downloads the server.met file from given URL and adds any new servers found
 * to server list.
 */
void CServerWnd::UpdateFromURL() {
	AddLogLine(wxT("Update Server List from URL button clicked."), 
			ID_DEBUGLOG);
}
