/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <alo17@hot.ee>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "xMuleDlg.h"
#endif

// For compilers that support precompilation
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "xMuleDlg.h"

/*
 * xMuleDlg class. The main dialog functions like Toolbar and Statusbar
 * stuff go in here.
 */

BEGIN_EVENT_TABLE(xMuleDlg,wxFrame)
	EVT_MENU(ID_QUIT, xMuleDlg::OnQuit)
	EVT_CLOSE(xMuleDlg::OnCloseWindow)
	EVT_TOOL(ID_BTN_CONNECT, xMuleDlg::OnBtnConnect)
	EVT_TOOL(ID_BTN_SERVERS, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_SEARCH, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_TRANSFER, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_SHARED, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_MESSAGES, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_STATISTICS, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_PREFERENCES, xMuleDlg::OnBtnPreferences)
END_EVENT_TABLE()

/*
 * Main dialog constructor. Creates toolbar on the top, statusbar on the
 * bottom and loads the sub-dialogs (serverwnd, searchwnd etc).
 */
xMuleDlg::xMuleDlg(
	wxWindow *parent, wxWindowID id, const wxString &title,
	const wxPoint &position, const wxSize& size, long style
) 
: wxFrame( parent, id, title, position, size, style ) {
	
	CreateMyToolBar();
	m_statusbar = new StatusBar(this);
	SetStatusBar(m_statusbar);
	
	wxIcon icon;
	icon.CopyFromBitmap(Icons(10));
	SetIcon(icon);
	
	serverwnd = new CServerWnd(this);
	searchwnd = new CSearchWnd(this);
	searchwnd->Hide();
	transferwnd = new CTransferWnd(this);
	transferwnd->Hide();
	sharedfileswnd = new CSharedFilesWnd(this);
	sharedfileswnd->Hide();
	messageswnd = new CMessagesWnd(this);
	messageswnd->Hide();
	statisticswnd = new CStatisticsWnd(this);
	statisticswnd->Hide();
	
	prefsdlg = new CPreferencesDlg(NULL, -1, wxT("Preferences"), 
				wxDefaultPosition, wxDefaultSize);
	
	tb->ToggleTool(ID_BTN_SERVERS, true);
	m_lastbtn = ID_BTN_SERVERS;

	/* This adds a new sizer in the frame to make switching pages easier. */
	m_mainsizer = ContentSizer(this, true);
	m_mainsizer->Add(serverwnd, 1, wxALIGN_LEFT|wxEXPAND|wxALL);
	serverwnd->Show();
	activewnd = serverwnd;
	Layout();
	SetSize(800, 600);
	
	serverwnd->AddLogLine(wxT("xMule v2 ready!"), ID_LOG, true);
}

/*
 * Destructor for xMuleDlg.
 */
xMuleDlg::~xMuleDlg() {
	delete serverwnd;
	delete searchwnd;
	delete transferwnd;
	delete sharedfileswnd;
	delete messageswnd;
//	delete statisticswnd;
	delete prefsdlg;
}

/*
 * Changes content of the main frame by removing the old panel from m_mainsizer
 * and attaching new one.
 */
void xMuleDlg::SetActiveDialog(wxWindow* dlg) {
	activewnd->Show(FALSE);
	m_mainsizer->Remove(activewnd);
	m_mainsizer->Add(dlg,1,wxALIGN_LEFT|wxEXPAND|wxALL);
	dlg->Show(TRUE);
	activewnd=dlg;
	Layout();
}

/*
 * Creates the toolbar on the top end of the main dialog.
 */
void xMuleDlg::CreateMyToolBar() {

	tb = CreateToolBar(
 		wxTB_HORIZONTAL|wxNO_BORDER|wxTB_TEXT|wxTB_FLAT|wxTB_3DBUTTONS
   	);
	tb->SetToolBitmapSize(wxSize(32, 32));
	MainToolbar( tb );
}

/*
 * Main dialog quit event. All main shutdown calls go in here.
 */
void xMuleDlg::OnQuit( wxCommandEvent &event ) {
	Close( TRUE );
}

/*
 * CloseWindow event function. This should destroy all open dialogs.
 */
void xMuleDlg::OnCloseWindow( wxCloseEvent &event ){
	Destroy();
}

/*
 * Handles main toolbar button click events. Toggles the previously clicked
 * button off and new button on. Then shows the correct dialog.
 */
void xMuleDlg::ToolbarButtonClicked (wxCommandEvent &event) {
	
	tb->ToggleTool(m_lastbtn, false);
	tb->ToggleTool(event.GetId(), true);
	m_lastbtn = event.GetId();

	switch (event.GetId()) {
		case ID_BTN_SERVERS: 
			SetActiveDialog(serverwnd);
			break;
		case ID_BTN_TRANSFER:
			SetActiveDialog(transferwnd);
			break;
		case ID_BTN_SEARCH:  
			SetActiveDialog(searchwnd);
			break;
		case ID_BTN_SHARED:
			SetActiveDialog(sharedfileswnd);
			break;
		case ID_BTN_MESSAGES:
			SetActiveDialog(messageswnd);
			break;
		case ID_BTN_STATISTICS:
			SetActiveDialog(statisticswnd);
			break;
		default:
			break;
	}
}

/*
 * Handles Connect button clicks on main toolbar. Switches button layout as
 * needed and sends message to core to connect/abort connecting/disconnect.
 */
void xMuleDlg::OnBtnConnect() {
}

/*
 * Handles Preferences button click on main toolbar. Displays the preferences
 * dialog.
 */
void xMuleDlg::OnBtnPreferences() {
	prefsdlg->ShowModal();
}
